@@ -37,4 +37,4 @@ class TextDataObject(NetBoxModel):
         return self.name
 
     def get_absolute_url(self):
-        return reverse('plugins:netbox_textdatastore:TextDataObject', args=[self.pk])
+        return reverse('plugins:netbox_textdatastore:textdataobject', args=[self.pk])
