@@ -2,7 +2,7 @@ from extras.plugins import PluginMenuItem
 
 menu_items = (
     PluginMenuItem(
-        link='plugins:netbox_textdatastore:TextDataObject_list',
+        link='plugins:netbox_textdatastore:textdataobject_list',
         link_text='Raw Data'
     ),
 )
